@@ -25,7 +25,7 @@ use std::fmt;
 ///
 /// Other RTCP packet types may follow in any order. Packet types may appear more than once.
 #[derive(Debug, Default, PartialEq, Clone)]
-pub struct CompoundPacket(pub Vec<Box<dyn Packet>>);
+pub struct CompoundPacket(pub Vec<Box<dyn Packet + Send + Sync>>);
 
 impl fmt::Display for CompoundPacket {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -56,18 +56,18 @@ impl Packet for CompoundPacket {
         l
     }
 
-    fn as_any(&self) -> &dyn Any {
+    fn as_any(&self) -> &(dyn Any + Send + Sync) {
         self
     }
 
-    fn equal(&self, other: &dyn Packet) -> bool {
+    fn equal(&self, other: &(dyn Packet + Send + Sync)) -> bool {
         other
             .as_any()
             .downcast_ref::<CompoundPacket>()
             .map_or(false, |a| self == a)
     }
 
-    fn cloned(&self) -> Box<dyn Packet> {
+    fn cloned(&self) -> Box<dyn Packet + Send + Sync> {
         Box::new(self.clone())
     }
 }
