@@ -72,18 +72,18 @@ impl Packet for ReceiverEstimatedMaximumBitrate {
         HEADER_LENGTH + REMB_OFFSET + self.ssrcs.len() * 4
     }
 
-    fn as_any(&self) -> &dyn Any {
+    fn as_any(&self) -> &(dyn Any + Send + Sync) {
         self
     }
 
-    fn equal(&self, other: &dyn Packet) -> bool {
+    fn equal(&self, other: &(dyn Packet + Send + Sync)) -> bool {
         other
             .as_any()
             .downcast_ref::<ReceiverEstimatedMaximumBitrate>()
             .map_or(false, |a| self == a)
     }
 
-    fn cloned(&self) -> Box<dyn Packet> {
+    fn cloned(&self) -> Box<dyn Packet + Send + Sync> {
         Box::new(self.clone())
     }
 }
