@@ -65,18 +65,18 @@ impl Packet for SliceLossIndication {
         HEADER_LENGTH + SLI_OFFSET + self.sli_entries.len() * 4
     }
 
-    fn as_any(&self) -> &dyn Any {
+    fn as_any(&self) -> &(dyn Any + Send + Sync) {
         self
     }
 
-    fn equal(&self, other: &dyn Packet) -> bool {
+    fn equal(&self, other: &(dyn Packet + Send + Sync)) -> bool {
         other
             .as_any()
             .downcast_ref::<SliceLossIndication>()
             .map_or(false, |a| self == a)
     }
 
-    fn cloned(&self) -> Box<dyn Packet> {
+    fn cloned(&self) -> Box<dyn Packet + Send + Sync> {
         Box::new(self.clone())
     }
 }
